#!/bin/sh
# vim: ft=sh: set noet ts=4 sw=4:

#this works with vsftpd server on ubuntu
#sudo apt-get install vsftpd
#sudo mkdir /srv/ftp
#sudo usermod -d /srv/ftp ftp 
#sudo /etc/init.d/vsftpd restart
#source file name are relative to /srv/ftp directory

if [ -f /var/run/lrrsystem ]; then
    . /var/run/lrrsystem
fi

setting=$ROOTACT/lrr/com/system_setting.sh
if [ -f "$setting" ]; then
    . $setting
    . $ROOTACT/lrr/com/system_api.sh
fi


#default values
MD5VERIF=""
FORCED="0"
CONFIG=""
DNCONFIG=""
EXTRACT=""
RESTART=""
CFGTYPE=""
CFGHARD=""
[ -z "$FTPUSERDL" ] && FTPUSERDL=ftp
[ -z "$FTPPASSDL" ] && FTPPASSDL=
[ -z "$FTPHOSTDL" ] && FTPHOSTDL=${LRCPRIMARY}
[ -z "$FTPPORTDL" ] && FTPPORTDL=21
[ -z "$USE_SFTP" ] && USE_SFTP=0

case	$# in
	*)
		while	[ $# -gt 0 ]
		do
			case	$1 in
				-F)
					shift
					FORCED="${1}"
					shift
				;;
				-M)
					shift
					MD5VERIF="${1}"
					shift
				;;
				-A)
					shift
					FTPHOSTDL="${1}"
					shift
				;;
				-P)
					shift
					FTPPORTDL="${1}"
					shift
				;;
				-U)
					shift
					FTPUSERDL="${1}"
					shift
				;;
				-W)
					shift
					FTPPASSDL="${1}"
					shift
				;;
				-C)
					shift
					CONFIG="${1}"
					shift
				;;
				-H)
					shift
					CFGHARD="$1"
					shift
				;;
				-E)
					shift
					WAIT="-E"
				;;
				-R)
					shift
					EXTRACT="1"
				;;
				-S)
					shift
					RESTART="${1}"
					shift
				;;
				-T)
					shift
					CFGTYPE="${1}"
					shift
				;;
				-X)
					shift
					USE_SFTP="${1}"
					shift
				;;
				*)

					shift
				;;
			esac
		done
	;;
esac

export PATH=.:$PATH

if	[ -z "$ROOTACT" ]
then
	if	[ -d /mnt/fsuser-1/actility ]
	then
		export ROOTACT=/mnt/fsuser-1/actility
	else
		export ROOTACT=/home/actility
	fi
fi

if [ -f ${ROOTACT}/lrr/com/_parameters.sh ]
then
	. ${ROOTACT}/lrr/com/_parameters.sh
fi
if [ -f ${ROOTACT}/lrr/com/_functions.sh ]
then
	. ${ROOTACT}/lrr/com/_functions.sh
fi

cd $ROOTACT

if	[ "$FORCED" = "0" ]
then
	if	[ -f $ROOTACT/usr/etc/lrr/dnconfig_locked ]
	then
		echo	"auto config feature disabled by ~/usr/etc/lrr/dnconfig_locked"
		exit 1
	fi
fi

LOCALCOPY=$(getIniConf $ROOTACT/usr/etc/lrr/lrr.ini "lrr" "rfregionrepo")
if [ "$LOCALCOPY" = "1" ]
then
	LOCALDIR=$(getIniConf $ROOTACT/usr/etc/lrr/lrr.ini "lrr" "rfregionsdir")
	[ -z "$LOCALDIR" ] && LOCALDIR="usr/etc/lrr/rfregions"
	isabsolute=$(echo "$LOCALDIR" | grep "^/")
	[ -z "$isabsolute" ] && LOCALDIR="$ROOTACT/$LOCALDIR"
fi

if	[ -z "$CONFIG" ]
then
	FILESRC="cfglrr-${LRRID}.tar.gz"
	FILEDST="/tmp/cfglrr-${LRRID}.tar.gz"
	FILESRCMD5="cfglrr-${LRRID}.md5"
	FILEDSTMD5="/tmp/cfglrr-${LRRID}.md5"
	DNCONFIG=${LRRID}
else
	if [ ! -z "$CFGHARD" ]
	then
		CFGVER="_v2"
		if [ ! -z "$SEMTECH_REFDESIGN" ]; then
			if [ "$SEMTECH_REFDESIGN" != "2.1" ]; then
				CFGVER="_v1"
			fi
		else
		    [ "$SYSTEM" != "wirmaar" -a "$SYSTEM" != "ciscoms" -a "$SYSTEM" != "tektelic" -a "$SYSTEM" != "tek_macro16" -a "$SYSTEM" != "tek_micro8" -a "$SYSTEM" != "fcloc" -a "$SYSTEM" != "tek_dish64" -a "$SYSTEM" != "mtcdt_ip67_v2.1" ] && CFGVER="_v1"
		fi
		CFGHARD="-CONF_${CFGHARD}${CFGVER}"
	fi
	FILESRC="cfglrr-${CONFIG}${CFGHARD}.tar.gz"
	FILEDST="/tmp/cfglrr-${CONFIG}.tar.gz"
	FILESRCMD5="cfglrr-${CONFIG}${CFGHARD}.md5"
	FILEDSTMD5="/tmp/cfglrr-${CONFIG}.md5"
	DNCONFIG=${CONFIG}
fi

if	[ -f "$FILEDST" ]
then
	echo	"rm $FILEDST"
	rm $FILEDST
fi
if	[ -f "$FILEDSTMD5" ]
then
	echo	"rm $FILEDSTMD5"
	rm $FILEDSTMD5
fi

if [ "$LOCALCOPY" = "1" ]
then
	text="local copy"
	echo "cp ${LOCALDIR}/${FILESRC} ${FILEDST}"
	cp ${LOCALDIR}/${FILESRC} ${FILEDST}
	res=$?
else
	text="lrr_DownloadFromRemote"
	echo "lrr_DownloadFromRemote -u ${FTPUSERDL} -w <password> -a ${FTPHOSTDL} -p ${FTPPORTDL} -l ${FILEDST} -r ${FILESRC} -s ${USE_SFTP}"
	lrr_DownloadFromRemote -u ${FTPUSERDL} -w ${FTPPASSDL} -a ${FTPHOSTDL} -p ${FTPPORTDL} -l ${FILEDST} -r ${FILESRC} -s ${USE_SFTP}
	res=$?
fi

if [ "$res" != "0" ]
then                     
	echo    "$text failure $FILEDST"
	if [ -f "$LRR_CMD_LOG" ]; then
		cat $LRR_CMD_LOG
	fi
	echo    "lrr_DownloadFromRemote failure $FILEDST not downloaded"
	exit 1
fi   
if [ ! -s "$FILEDST" ]
then
	echo	"$text failure $FILEDST size = 0"
	exit 1
fi

type md5sum > /dev/null 2>&1
if [ $? != 0 ]
then
	MD5VERIF=no
	echo	"md5sum command not found => no md5 check"
fi
if	[ "$MD5VERIF" != "no" ]
then
	if	[ -z "$MD5VERIF" ]
	then
		if [ "$LOCALCOPY" = "1" ]
		then
			echo "cp ${LOCALDIR}/${FILESRCMD5} ${FILEDSTMD5}"
			cp ${LOCALDIR}/${FILESRCMD5} ${FILEDSTMD5}
		else
			echo "lrr_DownloadFromRemote -u ${FTPUSERDL} -w <password> -a ${FTPHOSTDL} -p ${FTPPORTDL} -l ${FILEDSTMD5} -r ${FILESRCMD5} -s ${USE_SFTP}"
			lrr_DownloadFromRemote -u ${FTPUSERDL} -w ${FTPPASSDL} -a ${FTPHOSTDL} -p ${FTPPORTDL} -l ${FILEDSTMD5} -r ${FILESRCMD5} -s ${USE_SFTP}
		fi
		if	[ -s "${FILEDSTMD5}" ]
		then
			MD5VERIF=`cat $FILEDSTMD5 | tr -d '\015'`
			echo	"md5 $MD5VERIF from $FILEDSTMD5"
		else
			if [ -f "$LRR_CMD_LOG" ]; then
				cat $LRRCMD_LOG
			fi
			echo	"md5 file not downloaded/copied"
			exit 1
		fi
	fi
	MD5SUM=`md5sum $FILEDST`
	set $MD5SUM
	echo $1
	if	[ "${1}" != "$MD5VERIF" ]
	then
		echo	"wrong md5sum check"
		echo	"$MD5SUM"
		echo	"$MD5VERIF"
		rm $FILEDST
		exit 1
	fi
	echo	"file $FILEDST downloaded and verified (md5sum)"
else
	echo	"file $FILEDST downloaded and not verified (no md5sum)"
fi

if	[ -z "${EXTRACT}" ]
then
	cd $ROOTACT/usr/etc/lrr
else
	cd $ROOTACT
fi


# Check current ismband
ISMBAND_PREV=""
ISMBAND_PREV=$(check_config_key "band" $ROOTACT/lrr/config/lrr.ini $ISMBAND_PREV)
ISMBAND_PREV=$(check_config_key "band" $ROOTACT/usr/etc/lrr/lrr.ini $ISMBAND_PREV)
ISMBAND_PREV=$(check_config_key "band" $ROOTACT/usr/etc/lrr/lgw.ini $ISMBAND_PREV)

ISMBANDALTER_PREV=""
ISMBANDALTER_PREV=$(check_config_key "bandalter" $ROOTACT/lrr/config/lrr.ini $ISMBANDALTER_PREV)
ISMBANDALTER_PREV=$(check_config_key "bandalter" $ROOTACT/usr/etc/lrr/lrr.ini $ISMBANDALTER_PREV)
ISMBANDALTER_PREV=$(check_config_key "bandalter" $ROOTACT/usr/etc/lrr/lgw.ini $ISMBANDALTER_PREV)

FEATURE_LBT_PREV=""
FEATURE_LBT_PREV=$(getIniConf $ROOTACT/usr/etc/lrr/lgw.ini "lbt" "enable")
if [ -z $FEATURE_LBT_PREV ]; then
	FEATURE_LBT_PREV="0"
fi

case	${CFGTYPE} in
	rfregion)
		echo "check presence of lgw.ini and channels.ini"
		tar ztvf $FILEDST lgw.ini channels.ini
		if [ $? != "0" ]
		then
			echo "tar does not contains lgw.ini and channels.ini"
			exit 1
		fi
		tar zxvf $FILEDST
		sleep 1
		echo	${DNCONFIG} > $ROOTACT/usr/etc/lrr/dnrfregion_last
		RESTART="radiorestart"
	;;
	*)
		tar zxvf $FILEDST
		sleep 1
		echo	${DNCONFIG} > $ROOTACT/usr/etc/lrr/dnconfig_last
	;;
esac


if [ -z $RADIORESTART ]; then
	ISMBAND=""
	ISMBAND=$(check_config_key "band" $ROOTACT/lrr/config/lrr.ini $ISMBAND)
	ISMBAND=$(check_config_key "band" $ROOTACT/usr/etc/lrr/lrr.ini $ISMBAND)
	ISMBAND=$(check_config_key "band" $ROOTACT/usr/etc/lrr/lgw.ini $ISMBAND)

	ISMBANDALTER=""
	ISMBANDALTER=$(check_config_key "bandalter" $ROOTACT/lrr/config/lrr.ini $ISMBANDALTER)
	ISMBANDALTER=$(check_config_key "bandalter" $ROOTACT/usr/etc/lrr/lrr.ini $ISMBANDALTER)
	ISMBANDALTER=$(check_config_key "bandalter" $ROOTACT/usr/etc/lrr/lgw.ini $ISMBANDALTER)

	echo "previous ism band: band=$ISMBAND_PREV, bandalter=$ISMBANDALTER_PREV"
	echo "new      ism band: band=$ISMBAND, bandalter=$ISMBANDALTER"
	if [ "$ISMBAND_PREV" != "$ISMBAND" ] || [ "$ISMBANDALTER_PREV" != "$ISMBANDALTER" ]; then
		# need restart the LRR process RDTP-4402
		echo "New ISM band detected. Need LRR restart"
		RESTART="lrrrestart"
	else
		echo "New ISM band not detected. No need to force LRR restart"
	fi
	# RDTP-7315
	FEATURE_LBT=""
	FEATURE_LBT=$(getIniConf $ROOTACT/usr/etc/lrr/lgw.ini "lbt" "enable")
	if [ -z $FEATURE_LBT ]; then
		FEATURE_LBT="0"
	fi
	echo "previous LBT feature: $FEATURE_LBT_PREV"
	echo "new      LBT feature: $FEATURE_LBT"
	if [ "$FEATURE_LBT_PREV" != "$FEATURE_LBT" ]; then
		echo "LBT feature (de)activation detected. Need LRR restart"
		RESTART="lrrrestart"
	else
		echo "LBT feature (de)activation not detected. No need to force LRR restart"
	fi
fi


if	[ "$RESTART" = "lrrrestart" ]
then
	$ROOTACT/lrr/com/cmd_shells/restart.sh $WAIT
	exit $?
fi
if	[ "$RESTART" = "radiorestart" ]
then
	echo	"Request radio restart"
	touch	"/tmp/lrrradiorestart"
fi

exit $?
